from typing import Any, Callable, Dict, Optional

import attr

from ..types import UNSET
from ..util.serialization import is_not_none


@attr.s(auto_attribs=True)
class TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors:
    """  """

    def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:

        dct = {k: v for k, v in {}.items() if v != UNSET}
        if pick_by_predicate is not None:
            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
        return dct

    @staticmethod
    def from_dict(d: Dict[str, Any]) -> "TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors":
        return TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors()
